==> enterprisemodules-ora_config-3.9.9.tar.gz: enterprisemodules-ora_config-3.9.9/lib/puppet/type/ora_tablespace/datafile.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:datafile, :array_matching => :all) do
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Oracle::DatafileProperty
  include Puppet_X::EnterpriseModules::Oracle::Information

  desc <<-EOD
    The name of the datafile.
    This property can be either specified as String or as Array when using multiple datafiles.
    When using Oracle Managed Files omit this property and use num_datafiles instead.
  EOD

  data_type("Optional[Variant[Array[String[1]],String[1]]]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('FILE_NAME').split(';')
  end

  def insync?(value)
    #
    # If oracle managed files is enabled, we want to treat this property as a parameter
    # ando not do any modification on it. You should use the num_file property to manage
    # the datafiles then. You can however use the thios property in a create action.
    #
    return true if oracle_managed_files_enabled?(resource.sid)
    super(value)
  end

  validate do |_value|
    # TODO: Check if shouldorig is the way to address this variable
    fail 'oracle managed files not used and no datafile specified' if shouldorig.nil? && db_create_file_dest(resource.sid) == ''
  end

  on_modify do
    fail 'removing datafiles from tablespaces is not supported' if datafile_removed?
    fail 'cannot add datafiles to bigfile tablespace' if provider.bigfile.to_s == 'yes'
    add_df = resource.datafile - provider.datafile
    add_df.each do |df|
      sql "alter tablespace #{resource[:tablespace_name]} add #{file_type} '#{df}' size #{resource[:size]} #{autoextend_spec}", :sid => resource.sid
    end
  end

  def datafile_removed?
    provider.datafile.any? { |df| !resource.datafile.include?(df) }
  end
end

==> enterprisemodules-ora_config-3.12.0.tar.gz: enterprisemodules-ora_config-3.12.0/lib/puppet/type/ora_tablespace/datafile.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:datafile, :array_matching => :all) do
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Oracle::DatafileProperty
  include Puppet_X::EnterpriseModules::Oracle::Information

  desc <<-EOD
    The name of the datafile.
    This property can be either specified as String or as Array when using multiple datafiles.
    When using Oracle Managed Files omit this property and use num_datafiles instead.
  EOD

  data_type("Optional[Variant[Array[String[1]],String[1]]]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('FILE_NAME').split(';')
  end

  def to_s
    #
    # If Oracle managed files is enabled we don't expose thie property
    #
    return '' if oracle_managed_files_enabled?(resource.sid)
    super
  end

  def insync?(value)
    #
    # If oracle managed files is enabled, we want to treat this property as a parameter
    # ando not do any modification on it. You should use the num_file property to manage
    # the datafiles then. You can however use the this property in a create action.
    #
    return true if oracle_managed_files_enabled?(resource.sid)
    super(value)
  end

  validate do |_value|
    # TODO: Check if shouldorig is the way to address this variable
    fail 'oracle managed files not used and no datafile specified' if shouldorig.nil? && db_create_file_dest(resource.sid) == ''
  end

  on_modify do
    fail 'removing datafiles from tablespaces is not supported' if datafile_removed?
    fail 'cannot add datafiles to bigfile tablespace' if provider.bigfile.to_s == 'yes'
    add_df = resource.datafile - provider.datafile
    add_df.each do |df|
      sql "alter tablespace #{resource[:tablespace_name]} add #{file_type} '#{df}' size #{resource[:size]} #{autoextend_spec}", :sid => resource.sid
    end
  end

  def datafile_removed?
    provider.datafile.any? { |df| !resource.datafile.include?(df) }
  end
end
